@@ -12,11 +12,11 @@
 #include <qpainter.h>
 #include <qpixmap.h>
 #include <qtabbar.h>
-#include <qtabwidget.h>
 
 #include <kconfig.h>
 #include <klocale.h>
 #include <kglobal.h>
+#include <ktabwidget.h>
 
 #include "counter.h"
 #include "libkdeedu/kdeeduui/kedufontutils.h"
@@ -119,10 +119,10 @@ QSize scoresWidget::calcSize()
 
 /* myTabWidget */
 
-class myTabWidget : public QTabWidget
+class myTabWidget : public KTabWidget
 {
 	public:
-		myTabWidget(QWidget *parent) : QTabWidget(parent) {}
+		myTabWidget(QWidget *parent) : KTabWidget(parent) {}
 		
 		QSize tabBarSizeHint() const
 		{
@@ -160,7 +160,7 @@ bool highScoreDialog::scoreGoodEnough(int level, int score)
 	QList< QPair<int, QString> >::iterator it, itEnd;
 	it = m_scores[level].begin();
 	itEnd = m_scores[level].end();
-	while (it != itEnd && (*it).first >= score) it++;
+	while (it != itEnd && (*it).first >= score) ++it;
 	
 	return (it != itEnd);
 }
@@ -171,7 +171,7 @@ void highScoreDialog::addScore(int level, int score, const QString &name)
 	QList< QPair<int, QString> >::iterator it, itEnd;
 	it = m_scores[level].begin();
 	itEnd = m_scores[level].end();
-	while (it != itEnd && (*it).first >= score) it++;
+	while (it != itEnd && (*it).first >= score) ++it;
 	
 	if (it != itEnd)
 	{
