@@ -40,8 +40,7 @@
 #include "search.h"
 #include "searchwidget.h"
 
-//TODO KDE 4.1
-//#include "tableinfowidget.h" 
+#include "tableinfowidget.h" 
 
 
 #include <config-kalzium.h>
@@ -65,11 +64,11 @@
 #include <QTimer>
 #include <QSvgGenerator>
 #include <QRegExp>
+#include <QDebug>
 
 #include <kmessagebox.h>
 #include <kconfigdialog.h>
 #include <kiconloader.h>
-#include <kdebug.h>
 #include <kaction.h>
 #include <kparts/part.h>
 #include <kselectaction.h>
@@ -82,20 +81,17 @@
 #include <kfiledialog.h>
 #include <KLocale>
 #include <KPluginLoader>
-
-//TODO KDE 4.1
-//#include <KTabWidget>
+#include <KTabWidget>
 
 #define PeriodicTableView_MARGIN          5
 #define IDS_ELEMENTINFO     7
 
-Kalzium::Kalzium()
-    : KXmlGuiWindow( 0 )
+Kalzium::Kalzium() : KXmlGuiWindow( 0 )
 {
 	setObjectName( "KalziumMainWindow" );
 
-    // adding the libkdeedu catalog
-    KGlobal::locale()->insertCatalog( "libkdeedu" );
+	// adding the libkdeedu catalog
+	KGlobal::locale()->insertCatalog( "libkdeedu" );
 
 	// reading the elements from file
 	KalziumDataObject::instance();
@@ -130,14 +126,13 @@ Kalzium::Kalzium()
         connect( m_PeriodicTableView, SIGNAL( SchemeChanged( KalziumSchemeType * ) ),
                         m_legendWidget, SLOT( setScheme( KalziumSchemeType * ) ) );
 
-        //TODO KDE 4.1
-//X         m_TableInfoWidget = new TableInfoWidget( this );
-//X         connect( m_PeriodicTableView, SIGNAL(TableTypeChanged( KalziumTableType* ) ),
-//X                         m_TableInfoWidget, SLOT( setTableType( KalziumTableType * ) ) );
+        m_TableInfoWidget = new TableInfoWidget( this );
+        connect( m_PeriodicTableView, SIGNAL(TableTypeChanged( KalziumTableType* ) ),
+                        m_TableInfoWidget, SLOT( setTableType( KalziumTableType * ) ) );
 
 	m_infoDialog = 0;
 	m_toolboxCurrent = 0;
-    m_exportDialog = 0;
+	m_exportDialog = 0;
 	m_prevNormalMode = KalziumPainter::NORMAL;
 
 	connect( m_PeriodicTableView, SIGNAL( ElementClicked( int ) ), this, SLOT( openInformationDialog( int ) ));
@@ -145,7 +140,6 @@ Kalzium::Kalzium()
 
 	// layouting
 	setCentralWidget( fakemain );
-
 	setupSidebars();
 	setupActions();
 
@@ -184,21 +178,35 @@ void Kalzium::setupActions()
     connect( export_action, SIGNAL( triggered( bool ) ), this, SLOT( slotShowExportDialog() ) );
 
     // the action for swiching look: color schemes and gradients
-    QStringList looklist;
     QStringList schemes = KalziumSchemeTypeFactory::instance()->schemes();
-    looklist << prependToListItems( schemes, ki18n( "Scheme: %1" ) );
-    looklist << prependToListItems( KalziumGradientTypeFactory::instance()->gradients(), ki18n( "Gradient: %1" ) );
-    look_action =  actionCollection()->add<KSelectAction>( "view_look" );
-    look_action->setText( i18n( "&Look" ) );
-    look_action->setItems(looklist);
-    connect( look_action, SIGNAL( triggered( int ) ), this, SLOT( slotSwitchtoLook( int ) ) );
-    // "reduced" version of view_look
+    QStringList gradients = QStringList("No Gradient");
+    gradients << KalziumGradientTypeFactory::instance()->gradients();
+
+    look_action_menu_schemes =  actionCollection()->add<KSelectAction>( "view_look_scheme" );
+    look_action_menu_schemes->setText( i18n( "&Scheme" ) );
+    look_action_menu_schemes->setItems(schemes);
+    connect(look_action_menu_schemes, SIGNAL(triggered(int)), this, SLOT(slotSwitchtoLookScheme(int)));
+
+    look_action_menu_gradients =  actionCollection()->add<KSelectAction>( "view_look_gradient" );
+    look_action_menu_gradients->setText( i18n( "&Gradient" ) );
+    look_action_menu_gradients->setItems(gradients);
+    connect(look_action_menu_gradients, SIGNAL(triggered(int)), this, SLOT(slotSwitchtoLookGradient(int)));
+
+    // the action for swiching look: schemes
     look_action_schemes = actionCollection()->add<KSelectAction>( "view_look_onlyschemes" );
     look_action_schemes->setText( i18n( "&Scheme" ) );
     look_action_schemes->setItems( schemes );
     look_action_schemes->setToolBarMode( KSelectAction::MenuMode );
     look_action_schemes->setToolButtonPopupMode( QToolButton::InstantPopup );
-    connect( look_action_schemes, SIGNAL( triggered( int ) ), this, SLOT( slotSwitchtoLook( int ) ) );
+    connect( look_action_schemes, SIGNAL( triggered( int ) ), this, SLOT( slotSwitchtoLookScheme( int ) ) );
+
+    // the action for swiching look: gradients
+    look_action_gradients = actionCollection()->add<KSelectAction>( "view_look_onlygradient" );
+    look_action_gradients->setText( i18n( "&Gradients" ) );
+    look_action_gradients->setItems( gradients );
+    look_action_gradients->setToolBarMode( KSelectAction::MenuMode );
+    look_action_gradients->setToolButtonPopupMode( QToolButton::InstantPopup );
+    connect( look_action_gradients, SIGNAL( triggered( int ) ), this, SLOT( slotSwitchtoLookGradient( int ) ) );
     
     // the action for swiching tables
     QStringList tablelist;
@@ -296,12 +304,19 @@ void Kalzium::setupActions()
     KStandardAction::preferences(this, SLOT(showSettingsDialog()), actionCollection());
     KStandardAction::quit( kapp, SLOT (closeAllWindows()),actionCollection() );
 
-    slotSwitchtoLook( Prefs::colorschemebox() );
+    m_legendWidget->LockWidget();
+
+    slotSwitchtoLookScheme( Prefs::colorschemebox() );
+    slotSwitchtoLookGradient( Prefs::colorgradientbox() );
+
     slotSwitchtoNumeration( Prefs::numeration() );
     slotSwitchtoTable( Prefs::table() );
     slotShowHideSidebar( m_SidebarAction->isChecked(), false );
     slotShowLegend( m_pLegendAction->isChecked(), false );
 
+    m_legendWidget->UnLockWidget();
+    m_legendWidget->updateContent();
+
     // set the shell's ui resource file
     setXMLFile("kalziumui.rc");
     setupGUI();
@@ -316,12 +331,11 @@ void Kalzium::setupSidebars()
     
     m_InfoDock->setWidget(m_legendWidget);
 
-    //TODO KDE 4.1
-//X     m_infoTabWidget = new KTabWidget(this);
-//X     m_infoTabWidget->setObjectName( "kalzium-infobar" );
-//X     m_InfoDock->setWidget(m_infoTabWidget);
-//X     m_infoTabWidget->addTab(m_legendWidget, i18n("Legend"));
-//X     m_infoTabWidget->addTab(m_TableInfoWidget, i18n("Table Information"));
+    m_infoTabWidget = new KTabWidget(this);
+    m_infoTabWidget->setObjectName( "kalzium-infobar" );
+    m_InfoDock->setWidget(m_infoTabWidget);
+    m_infoTabWidget->addTab(m_legendWidget, i18n("Legend"));
+    m_infoTabWidget->addTab(m_TableInfoWidget, i18n("Table Information"));
 
     m_dockWin = new QDockWidget( this );
     m_dockWin->setObjectName( QLatin1String( "kalzium-sidebar" ) );
@@ -460,7 +474,7 @@ void Kalzium::slotShowLegend( bool checked, bool changeconfig)
 
 	if ( changeconfig )
 	{
-        Prefs::setShowlegend( checked );
+		Prefs::setShowlegend( checked );
 		//save the settings
 		Prefs::self()->writeConfig();
 	}
@@ -503,36 +517,80 @@ void Kalzium::slotSwitchtoNumeration( int index )
 	Prefs::self()->writeConfig();
 }
 
-void Kalzium::slotSwitchtoLook( int which )
+void Kalzium::slotSwitchtoLookGradient( int which )
 {
-    int id = which - KalziumSchemeTypeFactory::instance()->schemes().count();
-    if ( id < 0 )
-    {
-        m_PeriodicTableView->activateColorScheme( which );
-        if ( m_PeriodicTableView->mode() == KalziumPainter::GRADIENT )
-        {
-            m_PeriodicTableView->setMode( KalziumPainter::NORMAL );
-            m_legendWidget->setMode( KalziumPainter::NORMAL );
-        }
-    }
-    else
-    {
-        m_PeriodicTableView->setGradient( id );
-        if ( m_PeriodicTableView->mode() == KalziumPainter::NORMAL )
-        {
-            m_PeriodicTableView->setMode( KalziumPainter::GRADIENT );
-            m_legendWidget->setMode( KalziumPainter::GRADIENT );
-        }
-    }
-    look_action->blockSignals( true );
-    look_action_schemes->blockSignals( true );
-    look_action->setCurrentItem( which );
-    look_action_schemes->setCurrentItem( which );
-    look_action->blockSignals( false );
-    look_action_schemes->blockSignals( false );
+	kDebug() << "slotSwitchtoLookGradient Kalzium";
+	Prefs::setColorgradientbox(which);
+	Prefs::self()->writeConfig();
+	if (which > 0)
+	{
+		m_PeriodicTableView->setGradient( which - 1 );
+		if (m_PeriodicTableView->scheme()->name() == "Iconic" ||
+			m_PeriodicTableView->scheme()->name() == "MonoColor")
+		{
+			if (m_PeriodicTableView->mode() == KalziumPainter::NORMAL ||
+				m_PeriodicTableView->mode() == KalziumPainter::NORMAL_GRADIENT)
+			{
+				m_PeriodicTableView->setMode( KalziumPainter::GRADIENT );
+				m_legendWidget->setMode( KalziumPainter::GRADIENT );
+			}
+		}
+		else
+		{
+			if (m_PeriodicTableView->mode() == KalziumPainter::NORMAL ||
+				m_PeriodicTableView->mode() == KalziumPainter::GRADIENT)
+			{
+				m_PeriodicTableView->setMode( KalziumPainter::NORMAL_GRADIENT );
+				m_legendWidget->setMode( KalziumPainter::NORMAL_GRADIENT );
+			}
+		}
+	}
+	else
+		slotSwitchtoLookScheme( Prefs::colorschemebox() );
 
-    Prefs::setColorschemebox(which);
-    Prefs::self()->writeConfig();
+	look_action_menu_gradients->blockSignals( true );
+	look_action_gradients->blockSignals( true );
+	look_action_menu_gradients->setCurrentItem( which );
+	look_action_gradients->setCurrentItem( which );
+	look_action_menu_gradients->blockSignals( false );
+	look_action_gradients->blockSignals( false );
+}
+
+void Kalzium::slotSwitchtoLookScheme( int which )
+{
+	kDebug() << "slotSwitchtoLookScheme Kalzium";
+	m_PeriodicTableView->activateColorScheme( which );
+	if (Prefs::colorgradientbox() == 0 || m_PeriodicTableView->scheme()->name() == "Iconic" ||
+		m_PeriodicTableView->scheme()->name() == "MonoColor")
+	{
+		if (m_PeriodicTableView->mode() == KalziumPainter::GRADIENT ||
+			m_PeriodicTableView->mode() == KalziumPainter::NORMAL_GRADIENT)
+		{
+			m_PeriodicTableView->setMode( KalziumPainter::NORMAL );
+			m_legendWidget->setMode( KalziumPainter::NORMAL );
+		}
+	}
+	else
+	{
+		if (m_PeriodicTableView->mode() == KalziumPainter::GRADIENT ||
+			m_PeriodicTableView->mode() == KalziumPainter::NORMAL)
+		{
+			m_PeriodicTableView->setMode( KalziumPainter::NORMAL_GRADIENT );
+			m_legendWidget->setMode( KalziumPainter::NORMAL_GRADIENT );
+		}
+	}
+	
+	
+
+	look_action_menu_schemes->blockSignals( true );
+	look_action_schemes->blockSignals( true );
+	look_action_menu_schemes->setCurrentItem( which );
+	look_action_schemes->setCurrentItem( which );
+	look_action_menu_schemes->blockSignals( false );
+	look_action_schemes->blockSignals( false );
+
+	Prefs::setColorschemebox(which);
+	Prefs::self()->writeConfig();
 }
 
 void Kalzium::showSettingsDialog()
@@ -590,9 +648,7 @@ void Kalzium::setupStatusBar()
 
 void Kalzium::elementHover( int num )
 {
-    //TODO KDE 4.1
-    //In KDE 4.1 I want to display additional information about the icons. Then I need the next line
-//        extractIconicInformationAboutElement( num );
+        extractIconicInformationAboutElement( num );
 
 	Element *e = KalziumDataObject::instance()->element( num );
 	statusBar()->changeItem( i18nc( "For example: \"Carbon (6), Mass: 12.0107 u\"", "%1 (%2), Mass: %3 u" ,
@@ -603,28 +659,28 @@ void Kalzium::elementHover( int num )
 	m_detailWidget->setBackgroundColor( m_PeriodicTableView->brushForElement( num ).color() );
 }
                 
-//X void Kalzium::extractIconicInformationAboutElement( int elementNumber )
-//X {
-//X         QString setname = "school";
-//X         QString pathname = KGlobal::dirs()->findResourceDir( "appdata", "data/iconsets/" ) + "data/iconsets/";
-//X         QString filename = pathname + setname + '/' + "iconinformation.txt";
-//X 
-//X         QFile file(filename);
-//X         if (!file.open(QIODevice::ReadOnly | QIODevice::Text))
-//X                 return;
-//X 
-//X         QString infoline;
-//X 
-//X         QTextStream in(&file);
-//X         while (!in.atEnd()) {
-//X                 QString tmp = in.readLine();
-//X                 if( tmp.startsWith( QString::number( elementNumber ) ) )
-//X                         infoline = tmp;
-//X         }
-//X 
+void Kalzium::extractIconicInformationAboutElement( int elementNumber )
+{
+        QString setname = "school";
+        QString pathname = KGlobal::dirs()->findResourceDir( "appdata", "data/iconsets/" ) + "data/iconsets/";
+        QString filename = pathname + setname + '/' + "iconinformation.txt";
+
+        QFile file(filename);
+        if (!file.open(QIODevice::ReadOnly | QIODevice::Text))
+                return;
+
+        QString infoline;
+
+        QTextStream in(&file);
+        while (!in.atEnd()) {
+                QString tmp = in.readLine();
+                if( tmp.startsWith( QString::number( elementNumber ) ) )
+                        infoline = tmp;
+        }
+
+        QString realText = "Moin dies ist ein test!";
 //X         QString realText = infoline.remove( QRegExp("\\d+ ") );
-//X         kDebug() << "the final text: " << realText;
-//X }
+}
 
 void Kalzium::openInformationDialog( int number )
 {
@@ -648,7 +704,8 @@ void Kalzium::openInformationDialog( int number )
 void Kalzium::slotToolboxCurrentChanged( int id )
 {
     KalziumPainter::MODE cur = m_PeriodicTableView->mode();
-    if ( ( id > 1 ) && ( cur == KalziumPainter::NORMAL ) || ( cur == KalziumPainter::GRADIENT ) )
+    if ( ( id > 1 ) && (cur == KalziumPainter::NORMAL) || (cur == KalziumPainter::GRADIENT) ||
+	(cur == KalziumPainter::NORMAL_GRADIENT) )
         m_prevNormalMode = cur;
     m_PeriodicTableView->setMode( m_prevNormalMode );
     m_legendWidget->setMode( m_prevNormalMode );
