@@ -4,6 +4,10 @@
     begin                : Tue Nov 27 16:40:42 CET 2001
     copyright            : (C) 2001 by Sebastian Stein
     email                : seb.kde@hpfsc.de
+
+    copyright            : (C) 2008 by Tiago Porangaba, tiago.porangaba@ltia.fc.unesp.br
+    copyright            : (C) 2008 by Tadeu Araujo, tadeu.araujo@ltia.fc.unesp.br
+    copyright            : (C) 2008 by Danilo Balzaque, danilo.balzaque@ltia.fc.unesp.br
  ***************************************************************************/
 
 /***************************************************************************
@@ -42,13 +46,19 @@ int main(int argc, char * argv[])
 		KAboutData::License_GPL,
     	ki18n("(c) 2002-2004, Sebastian Stein"), KLocalizedString(), "http://edu.kde.org/kbruch/",
 		"seb.kde@hpfsc.de");
-	aboutData.addAuthor(ki18n("Sebastian Stein"),KLocalizedString(), "seb.kde@hpfsc.de");
+	aboutData.addAuthor(ki18n("Sebastian Stein"),ki18n("Original Author"),"seb.kde@hpfsc.de");
+	aboutData.addAuthor(ki18n("Paulo Cattai"),ki18n("New interface design and usability improvements"), "paulo.cattai@ltia.fc.unesp.br");
+	aboutData.addAuthor(ki18n("Danilo Balzaque"),ki18n("New interface design and usability improvements"), "danilo.balzaque@ltia.fc.unesp.br");
+	aboutData.addAuthor(ki18n("Roberto Cunha"),ki18n("New interface design and usability improvements"), "roberto.cunha@ltia.fc.unesp.br");
+	aboutData.addAuthor(ki18n("Tadeu Araujo"),ki18n("New interface design and usability improvements"), "tadeu.araujo@ltia.fc.unesp.br");
+	aboutData.addAuthor(ki18n("Tiago Porangaba"),ki18n("New interface design and usability improvements"), "tiago.porangaba@ltia.fc.unesp.br");
+
  	KCmdLineArgs::init( argc, argv, &aboutData );
 
 	KApplication kbruch;
 	QObject::connect(kapp, SIGNAL(lastWindowClosed()), kapp, SLOT(quit()));
 
-	MainQtWidget * kbruchApp = new MainQtWidget();
+	AppMenuWidget * kbruchApp = new AppMenuWidget();
 	kbruchApp->show();
 
 	/* lets execute the Qt GUI; it will handle all cmd options which are left */
