@@ -4,6 +4,10 @@
     begin                : Tue Nov 27 16:40:42 CET 2001
     copyright            : (C) 2001 by Sebastian Stein
     email                : seb.kde@hpfsc.de
+
+    copyright            : (C) 2008 by Tiago Porangaba, tiago.porangaba@ltia.fc.unesp.br
+    copyright            : (C) 2008 by Tadeu Araujo, tadeu.araujo@ltia.fc.unesp.br
+    copyright            : (C) 2008 by Danilo Balzaque, danilo.balzaque@ltia.fc.unesp.br
  ***************************************************************************/
 
 /***************************************************************************
@@ -47,30 +51,26 @@ task::~task()
  * can be customized by the given parameters:
  * pmax_md: maximum main denominator
  * pnr_ratios: number of ratios -> pnr_ratios - 1 operations
- * padd_sub: if true + and - are allowed operations
- * pmul_div: if true * and / are allowed operations */
+*/
 void task::create_task(unsigned int pmax_md, short pnr_ratios,
-                       short padd_sub, short pmul_div)
+                       short padd_add, short padd_div, 
+                       short padd_mult, short padd_sub)
 {
 	unsigned int max_product_length = 0;
 	int main_denominator = 1;
 
-	/* we say that if add/sub and mul/div are not allowed we want a task
-	 * for add/sub only */
-	if (padd_sub == NO && pmul_div == NO)
-		padd_sub = YES;
-
 	do
 	{
 		/* delete a maybe given task */
 		ratio_vector.clear();
 
 		/* generate the operations and count the max. mul/div in one block */
-		max_product_length = make_operation(padd_sub, pmul_div, pnr_ratios);
+		max_product_length = make_operation(padd_add, padd_div, padd_mult, padd_sub, pnr_ratios);
 
 #ifdef DEBUG
 		kDebug() << "1: max_product_length: " << max_product_length;
 #endif
+
 		/* later we must be able to find a main denominator;
 		 * so 2 ^ max_product_length couldn't be bigger than the max. denominator */
 	}
@@ -95,7 +95,7 @@ void task::create_task(unsigned int pmax_md, short pnr_ratios,
 #endif
 
 	/* create the ratios' denominators */
-	make_denominators(main_denominator, pmax_md, pmul_div);
+	make_denominators(main_denominator, pmax_md, padd_div, padd_mult);
 
 #ifdef DEBUG
 	kDebug() << "main deno: " << main_denominator;
@@ -180,6 +180,10 @@ void task::add_operation(short operation)
 /** just outputs the whole given task to stdout; for debugging */
 QTextStream & task::display(QTextStream & str)
 {
+#ifdef DEBUG
+	kDebug() << "task::display()";
+#endif
+
 	/* this is our pointer on the ratio_vector, set it to the beginning */
 	RatioArray::iterator ratio_pointer = ratio_vector.begin();
 
@@ -206,7 +210,7 @@ QTextStream & task::display(QTextStream & str)
 
 	/* display all numerators */
 	for (ratio_pointer = ratio_vector.begin();
-	        ratio_pointer != ratio_vector.end(); ratio_pointer++)
+	        ratio_pointer != ratio_vector.end(); ++ratio_pointer)
 	{
 		str << qSetFieldWidth(5) << ratio_pointer->numerator() << "   ";
 	}
@@ -218,7 +222,7 @@ QTextStream & task::display(QTextStream & str)
 
 	/* display all operations */
 	for (op_pointer = op_vector.begin();
-	        op_pointer != op_vector.end(); op_pointer++)
+	        op_pointer != op_vector.end(); ++op_pointer)
 	{
 		str << " ----- " << a[*op_pointer];
 	}
@@ -230,7 +234,7 @@ QTextStream & task::display(QTextStream & str)
 
 	/* display all denominators */
 	for (ratio_pointer = ratio_vector.begin();
-	        ratio_pointer != ratio_vector.end(); ratio_pointer++)
+	        ratio_pointer != ratio_vector.end(); ++ratio_pointer)
 	{
 		if (ratio_pointer == ratio_vector.end() - 1)
 			return str << qSetFieldWidth(5) << ratio_pointer->denominator() << "   ";
@@ -335,12 +339,18 @@ ratio task::solve()
 /* returns the number of ratios in the vector */
 int task::getNumberOfRatios() const
 {
+#ifdef DEBUG
+	kDebug() << "task::getNumberOfRatios()";
+#endif
 	return ratio_vector.count();
 }
 
 /* returns the number of operations in the vector */
 int task::getNumberOfOperations() const
 {
+#ifdef DEBUG
+	kDebug() << "task::getNumberOfOperations()";
+#endif
 	return op_vector.count();
 }
 
@@ -349,25 +359,26 @@ int task::getNumberOfOperations() const
 ratio task::product(RatioArray::iterator & ratio_pointer,
                     ShortArray::iterator & op_pointer)
 {
+#ifdef DEBUG
+	kDebug() << "task::product()";
+#endif	
 	/* the function's parameters are pointing to the next ratio;
 	 * to the starting point of the product */
 	ratio product(ratio_pointer->numerator(), ratio_pointer->denominator());
 
-#ifdef DEBUG
-
-	kDebug() << "in product()";
-#endif
-
 	++ratio_pointer;
 	do
 	{
 		switch (*op_pointer)
 		{
 		case ADD :
+			product = product + *ratio_pointer++;
+			++op_pointer;
+			break;
 		case SUB :
-			return product; /* finished */
-
-			/* compute the next step of the product (or div) */
+			product = product - *ratio_pointer++;
+			++op_pointer;
+			break;
 		case MUL :
 			product = product * *ratio_pointer++;
 			++op_pointer;
@@ -387,46 +398,95 @@ ratio task::product(RatioArray::iterator & ratio_pointer,
 
 /** generate the operations randomly; return how many mul or div
  * are in one block */
-unsigned short task::make_operation(short padd_sub, short pmul_div,
+unsigned short task::make_operation(short padd_add, short padd_div, short padd_mult, short padd_sub, 
                                     short pnr_ratios)
 {
+#ifdef DEBUG
+	kDebug() << "task::make_operation()";
+#endif
 	unsigned short max_product_length = 0;
 	unsigned short operations = 0;
+	unsigned short counter = 0;
 
 	/* this is our pointer on the op_vector, set it to the beginning */
 	ShortArray::iterator op_pointer;
 
-	/* we need this to generate the fitting operations */
-	if (padd_sub == YES)
-		operations += 2;
-	if (pmul_div == YES)
-		operations += 2;
-
 	/* clear the old operations */
 	op_vector.clear();
 
 	/* generate the operations */
-	for (short counter = 0; counter < pnr_ratios - 1; counter++)
-		op_vector.push_back(short((double(rand()) / RAND_MAX) * operations));
+	if (padd_add == YES && padd_div == NO && padd_mult == NO && padd_sub == NO) {
+						kDebug() << "11";
+		for (short counter = 0; counter < pnr_ratios - 1; counter++)
+			op_vector.push_back(ADD);
+	} else if (padd_div == YES && padd_add == NO && padd_mult == NO && padd_sub == NO) {
+						kDebug() << "22";
+		for (short counter = 0; counter < pnr_ratios - 1; counter++)
+			op_vector.push_back(DIV);
+	} else if (padd_mult == YES && padd_add == NO && padd_div == NO && padd_sub == NO) {
+						kDebug() << "33";
+		for (short counter = 0; counter < pnr_ratios - 1; counter++)
+			op_vector.push_back(MUL);
+	} else if (padd_sub == YES && padd_add == NO && padd_div == NO && padd_mult == NO) {
+						kDebug() << "44";
+		for (short counter = 0; counter < pnr_ratios - 1; counter++)
+			op_vector.push_back(SUB);
+	} else {	
+		do {
+			operations = short((double(rand()) / RAND_MAX) * 4);
+			switch (operations) {
+				case ADD:
+					if (padd_add == YES) {
+						op_vector.push_back(ADD);
+						counter++;
+						kDebug() << "1";
+					}
+					break;
+				case SUB:
+					if (padd_sub == YES) {
+						op_vector.push_back(SUB);
+						counter++;
+						kDebug() << "2";
+					}
+					break;
+				case DIV:
+					if (padd_div == YES) {
+						op_vector.push_back(DIV);
+						counter++;
+						kDebug() << "3";
+					}
+					break;
+				case  MUL:
+					if (padd_mult == YES) {
+						op_vector.push_back(MUL);
+						counter++;
+						kDebug() << "4";
+					}
+					break;				
+			}															
+		} while ( counter < (pnr_ratios - 1) );
+	}
 
 	/* if we only wanted mul/div, operations was 2; but we want values
 	 * for the operations with 2 and 3 so we have to add 2 */
-	if (padd_sub == NO && pmul_div == YES)
-	{
+	//if ( (padd_mult == YES || padd_div == YES) && (padd_add == NO && padd_sub == NO) )
+//	{
 		/* loop through all operations and add 2, so that the operations
 		 * are interpreted as mul/div and not add/sub */
-		for (op_pointer = op_vector.begin();
-		        op_pointer != op_vector.end(); op_pointer++)
-			*op_pointer += 2;
-	}
+//		for (op_pointer = op_vector.begin();
+		        //op_pointer != op_vector.end(); ++op_pointer) {
+//						kDebug() << "4";
+			//*op_pointer += 2;
+//}
+//	}
 
-	if (pmul_div == YES)
+	if (padd_mult == YES || padd_div == YES)
 	{
 		short flag_counter = 0;
 
 		/* loop through all operations */
 		for (op_pointer = op_vector.begin();
-		        op_pointer != op_vector.end(); op_pointer++)
+		        op_pointer != op_vector.end(); ++op_pointer)
 		{
 			/* look if we got a mul/div or add/sub */
 			if (*op_pointer == DIV || *op_pointer == MUL)
@@ -518,7 +578,7 @@ unsigned short task::prim_factor_nr(int number)
 	kDebug() << "Primfaktoren von: " << number;
 	for (prim_fac_pointer = prim_fac_vector.begin();
 	        prim_fac_pointer != prim_fac_vector.end();
-	        prim_fac_pointer++)
+	        ++prim_fac_pointer)
 		kDebug() << (*prim_fac_pointer).factor;
 	kDebug() << "Anzahl: " << prim_fac_vector.size();
 #endif
@@ -544,7 +604,7 @@ void task::make_numerators(int main_denominator, short pnr_ratios)
 
 /** create the ratios' denominators */
 void task::make_denominators(int main_denominator, short pmax_md,
-                             short pmul_div)
+                             short padd_div, short padd_mult)
 {
 	/* this is our pointer on the ratio_vector, set it to the beginning */
 	RatioArray::iterator ratio_pointer = ratio_vector.begin();
@@ -570,7 +630,7 @@ void task::make_denominators(int main_denominator, short pmax_md,
 
 	/* first make all denominators */
 	for (ratio_pointer = ratio_vector.begin();
-	        ratio_pointer != ratio_vector.end(); ratio_pointer++)
+	        ratio_pointer != ratio_vector.end(); ++ratio_pointer)
 	{
 		do
 		{
@@ -582,7 +642,7 @@ void task::make_denominators(int main_denominator, short pmax_md,
 
 	/* if the ratio is connected to a mul or div operation, we have to do some
 	 * extra work and regenerate the denominators */
-	if (pmul_div == YES)
+	if (padd_mult == YES || padd_div == YES)
 	{
 		/* lets loop through all ratios and check, if there is a mul/div
 		 * after the ratio */
@@ -596,7 +656,7 @@ void task::make_denominators(int main_denominator, short pmax_md,
 				 * reset the prime number structure */
 				for (prim_fac_pointer = prim_fac_vector.begin();
 				        prim_fac_pointer != prim_fac_vector.end();
-				        prim_fac_pointer++)
+				        ++prim_fac_pointer)
 					(*prim_fac_pointer).flag = UNUSED;
 
 				/* how many prime factors are available? */
@@ -615,7 +675,7 @@ void task::make_denominators(int main_denominator, short pmax_md,
 					/* check the prime factors, if they are unused */
 					for (prim_fac_pointer = prim_fac_vector.begin();
 					        prim_fac_pointer != prim_fac_vector.end();
-					        prim_fac_pointer++)
+					        ++prim_fac_pointer)
 					{
 						if ((*prim_fac_pointer).flag == UNUSED)
 						{
@@ -654,7 +714,7 @@ void task::make_denominators(int main_denominator, short pmax_md,
 					/* check the prime factors, if they are unused */
 					for (prim_fac_pointer = prim_fac_vector.begin();
 					        prim_fac_pointer != prim_fac_vector.end();
-					        prim_fac_pointer++)
+					        ++prim_fac_pointer)
 					{
 						if ((*prim_fac_pointer).flag == UNUSED)
 						{
@@ -691,7 +751,7 @@ void task::make_denominators(int main_denominator, short pmax_md,
 		ratio_pointer++;
 
 		for (op_pointer = op_vector.begin(); op_pointer != op_vector.end();
-		        op_pointer++)
+		        ++op_pointer)
 		{
 			if (*op_pointer == DIV)
 			{
