@@ -4,6 +4,10 @@
     begin                : Tue Nov 27 16:40:42 CET 2001
     copyright            : (C) 2001 by Sebastian Stein
     email                : seb.kde@hpfsc.de
+
+    copyright            : (C) 2008 by Tiago Porangaba, tiago.porangaba@ltia.fc.unesp.br
+    copyright            : (C) 2008 by Tadeu Araujo, tadeu.araujo@ltia.fc.unesp.br
+    copyright            : (C) 2008 by Danilo Balzaque, danilo.balzaque@ltia.fc.unesp.br
  ***************************************************************************/
 
 /***************************************************************************
@@ -75,7 +79,7 @@ public:
 
 	/** automatically generate a new task with the given parameters */
 	void create_task(unsigned int pmax_md = 10, short pnr_ratios = 2,
-	                 short padd_sub = YES, short pmul_div = NO);
+	                 short padd_add = YES, short padd_div = NO, short padd_mult = NO, short padd_sub = NO);
 
 	/** set ratio n */
 	void set_ratio_n(unsigned short number = 0, int numerator = 0,
@@ -121,11 +125,10 @@ private:
 	/** how many ratios should the task have */
 	short nr_ratios;
 
-	/** are add/sub operations allowed */
 	short add_sub;
-
-	/** are mul/div operations allowed */
-	short mul_div;
+	short add_add;
+	short add_mult;
+	short add_div;		
 
 	/** the ratio vector */
 	RatioArray ratio_vector;
@@ -143,8 +146,9 @@ private:
 
 	/** generate the operations randomly; return how many mul or div
 	 * are in one block */
-	unsigned short make_operation(short padd_sub, short pmul_div,
-	                              short pnr_ratios);
+	unsigned short make_operation(short padd_add = YES, short padd_div = NO, 
+				      short padd_mult = NO, short padd_sub = NO,
+	                              short pnr_ratios = 0);
 
 	/** find a denominator for the task */
 	int make_main_dn(unsigned int pmax_md, unsigned short max_product_length);
@@ -156,8 +160,8 @@ private:
 	void make_numerators(int main_denominator, short pnr_ratios);
 
 	/** create the ratios' denominators */
-	void make_denominators(int main_denominator, short pmax_md,
-	                       short pmul_div);
+	void make_denominators(int main_denominator = 0, short pmax_md = 0, 
+			       short padd_div = NO, short padd_mult = NO);
 };
 
 
