@@ -12,8 +12,8 @@
 
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-// 02111-1307, USA.
+// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+// 02110-1301, USA.
 
 #ifndef KIG_OBJECTS_OBJECT_IMP_H
 #define KIG_OBJECTS_OBJECT_IMP_H
@@ -27,7 +27,6 @@ class InvalidImp;
 class HierarchyImp;
 class TransformationImp;
 class TestResultImp;
-class CurveImp;
 class LineImp;
 class PointImp;
 class TextImp;
@@ -82,8 +81,8 @@ typedef unsigned int uint;
 /**
  * Instances of this class represent a certain ObjectImp type.  Every
  * ObjectImp type has a static ObjectImpType member, that it returns a
- * reference to in its type() function..  Think of it as a nice enum,
- * that you can also get some data from..
+ * reference to in its type() function.  Think of it as a nice enum,
+ * that you can also get some data from.
  */
 class ObjectImpType
 {
@@ -106,7 +105,7 @@ public:
    *
    * \internal Do *not* call this from functions that can be called at
    * static initializer time !  It depends on information that is only
-   * available after that stage and will crash if used too early..
+   * available after that stage and will crash if used too early.
    */
   static const ObjectImpType* typeFromInternalName( const char* n );
 
@@ -128,7 +127,7 @@ public:
    * All translatable strings should have
    * I18N_NOOP around them !  @param parent is the ObjectImpType of
    * your parent ObjectImp type.  Never give 0 as parent, except for
-   * the top ObjectImp ObjectImpType..
+   * the top ObjectImp ObjectImpType.
    */
   ObjectImpType(
     const ObjectImpType* parent, const char* internalname,
@@ -141,18 +140,19 @@ public:
     const char* attachtothisstatement,
     const char* showastatement,
     const char* hideastatement );
-  ~ObjectImpType();
+  virtual ~ObjectImpType();
 
   /**
    * Does the ObjectImp type represented by this instance inherit the
    * ObjectImp type represented by t ?
    */
   bool inherits( const ObjectImpType* t ) const;
+  virtual bool match( const ObjectImpType* t ) const;
 
   /**
    * Returns an internal name for this ObjectImp type.  This name is
    * guaranteed unique, and mostly corresponds with the class name of
-   * the corresponding ObjectImp..
+   * the corresponding ObjectImp.
    */
   const char* internalName() const;
   /**
@@ -213,7 +213,7 @@ public:
  * The ObjectImp class represents the behaviour of an object after it
  * is calculated.   This means how to draw() it, whether it claims to
  * contain a certain point etc.  It is also the class where the
- * ObjectType's get their information from..
+ * ObjectType's get their information from.
  */
 class ObjectImp
 {
@@ -226,6 +226,48 @@ public:
    */
   static const ObjectImpType* stype();
 
+  /**
+   * mp: The following three methods (getPropLid, getPropGid, getPropName)
+   * deal with the properties of ObjectImp(s).
+   * the properties architecture (vectors of properties associated to
+   * each Imp) didn't work at all in situation when a node in the object
+   * hierarchy of which a properties is used changes it's Imp dynamically.
+   * An example of this is a python script that constructs a "hyperbolic 
+   * segment" in the half-plane model of hyperbolic geometry, that results
+   * in a circular arc or a segment depending on the relative position of
+   * the two end-points.
+   * A workaround for this problem is to maintain two numberings for a
+   * property: the "local" id (Lid) is the index in the property vector
+   * associated to an ObjectImp, it makes only sense relatively to a
+   * specific ObjectImp; the "global" id (Gid) is a global numbering
+   * generated runtime and distinguishing properties only based on their
+   * internal name.
+   * A property node must only use the global numbering, so that when the
+   * parent changes it's Imp, the correct property (if it exists) of the
+   * new Imp will be used.
+   * the association of Gid to properties is constructed runtime whenever
+   * a new property is first used by populating a static vector
+   * (see object_imp.cc).
+   * The conversion Gid->Lid requires a vector search, so that a caching
+   * mechanism has been set up in the ObjectPropertyCalcer that stores the
+   * Lid and recalculates it when the typeid of the ObjectImp of the parent
+   * changes.
+   *
+   * getPropLid: returns the local numbering corresponding to a Gid
+   * getPropGid: returns the Gid of a property given its internal name
+   * getPropName: returns the internal name of a property given its Gid
+   *
+   * Note: in object_hierarchy.cc the class "FetchPropertyNode" is quite
+   * similar to "ObjectPropertyCalcer", and thus is similarly restructured.
+   * However the caching mechanism has not been setup in this case. 
+   * It seems that "FetchPropertyNode" is only used for the "drawprelim"
+   * in constructions that involve a macro that in turn involves a property,
+   * so perhaps the caching is not that important.
+   */
+  int getPropLid( int propgid ) const;
+  int getPropGid( const char *pname ) const;
+  const char* getPropName( int propgid ) const;
+
   virtual ~ObjectImp();
 
   /**
@@ -281,25 +323,25 @@ public:
    */
   bool valid() const;
 
-  virtual const uint numberOfProperties() const;
+  virtual int numberOfProperties() const;
   // the names of the properties as perceived by the user..  put
   // I18N_NOOP's around them here..
-  virtual const QCStringList properties() const;
+  virtual const QByteArrayList properties() const;
   // the names of the properties as known only by kig internally.  No
   // need for I18N_NOOP.  Preferably choose some lowercase name with
   // only letters and dashes, no spaces..
-  virtual const QCStringList propertiesInternalNames() const;
-  virtual ObjectImp* property( uint which, const KigDocument& d ) const;
+  virtual const QByteArrayList propertiesInternalNames() const;
+  virtual ObjectImp* property( int which, const KigDocument& d ) const;
   // Sometimes we need to know which type an imp needs to be at least
   // in order to have the imp with number which.  Macro's need it
   // foremost.  This function answers that question..
-  virtual const ObjectImpType* impRequirementForProperty( uint which ) const;
+  virtual const ObjectImpType* impRequirementForProperty( int which ) const;
   // Return whether the property with number which is by construction
   // always a point on this curve ( if this is a curve ), or always a
   // curve through this point ( if this is a curve ).
-  virtual bool isPropertyDefinedOnOrThroughThisImp( uint which ) const;
+  virtual bool isPropertyDefinedOnOrThroughThisImp( int which ) const;
   // What icon should be shown when talking about this property ?
-  virtual const char* iconForProperty( uint which ) const;
+  virtual const char* iconForProperty( int which ) const;
 
   /**
    * Returns the lowermost ObjectImpType that this object is an
@@ -343,7 +385,7 @@ public:
    * This function checks whether rhs is of the same ObjectImp type,
    * and whether it contains the same data as this ObjectImp.
    * \internal It is used e.g. by the KigCommand stuff to see what the
-   * user has changed during a move..
+   * user has changed during a move.
    */
   virtual bool equals( const ObjectImp& rhs ) const = 0;
 
@@ -352,7 +394,7 @@ public:
    * means that it will never be considered to be stored in a file or
    * in an ObjectHierarchy.  This is useful for objects which cannot
    * (easily and usefully) be (de)serialized, like e.g.
-   * PythonCompiledScriptImp..  For normal objects, the default
+   * PythonCompiledScriptImp.  For normal objects, the default
    * implementation returns false, which is fine.
    */
   virtual bool isCache() const;
