@@ -46,17 +46,21 @@
 #include "imageviewer.h"
 #include "infoboxes.h"
 #include "observinglist.h"
-#include "imagesequence.h"
 
 #include "kstarsadaptor.h"
 
+#include <config-kstars.h>
+
+#ifdef HAVE_INDI_H
 #include "indimenu.h"
 #include "indidriver.h"
+#include "imagesequence.h"
+#endif
 
 KStars::KStars( bool doSplash, bool clockrun, const QString &startdate ) :
         KXmlGuiWindow(), kstarsData(0), splash(0), skymap(0), TimeStep(0),
         colorActionMenu(0), fovActionMenu(0),
-        AAVSODialog(0), findDialog(0), obsList(0), avt(0), wut(0),
+        AAVSODialog(0), findDialog(0), obsList(0), avt(0), wut(0), skycal(0), 
         sb(0), pv(0), jmt(0), indimenu(0), indidriver(0), indiseq(0),
         DialogIsObsolete(false), StartClockRunning( clockrun ),
         StartDateString( startdate )
@@ -72,7 +76,7 @@ KStars::KStars( bool doSplash, bool clockrun, const QString &startdate ) :
 
     //reset date format to get rid of weekday
     QString fmt = KGlobal::locale()->dateFormat();
-    fmt = fmt.replace( "%A", "", Qt::CaseInsensitive );
+    fmt = fmt.remove( "%A", Qt::CaseInsensitive );
     KGlobal::locale()->setDateFormat( fmt );
 
     //Set Geographic Location from Options
