@@ -230,7 +230,7 @@ void modCalcGeodCoord::slotRunBatch(void) {
         if ( !f.open( QIODevice::ReadOnly) ) {
             QString message = i18n( "Could not open file %1.", f.fileName() );
             KMessageBox::sorry( 0, message, i18n( "Could Not Open File" ) );
-            inputFileName = QString();
+            inputFileName.clear();
             return;
         }
 
@@ -242,7 +242,7 @@ void modCalcGeodCoord::slotRunBatch(void) {
     } else  {
         QString message = i18n( "Invalid file: %1", inputFileName );
         KMessageBox::sorry( 0, message, i18n( "Invalid file" ) );
-        inputFileName = QString();
+        inputFileName.clear();
         InputFileBoxBatch->setUrl( inputFileName );
         return;
     }
@@ -275,7 +275,7 @@ void modCalcGeodCoord::processLines( QTextStream &istream ) {
 
         //Go through the line, looking for parameters
 
-        QStringList fields = line.split( " " );
+        QStringList fields = line.split( ' ' );
 
         i = 0;
 
