@@ -23,6 +23,10 @@ cat data/legend.html \
   | sed -e 's/^\(.*\)$/\/\/i18n: file .\/data\/legend.html\ni18n(\"\1\");/' \
   >> rc.cpp
 
+# Eliminate empty i18n calls.
+egrep -B1 'i18nc?\(".*[^ ].*"\)' rc.cpp > rc.cpp.1
+mv rc.cpp.1 rc.cpp
+
 $EXTRACTRC `find . -name '*.ui' -o -name '*.rc'` >> rc.cpp
-$XGETTEXT -ktr:1,1t -ktr:1,2c,2t -kQT_TRANSLATE_NOOP:1c,2,2t -kQT_TR_NOOP:1,1t -ktranslate:1c,2,2t -ktranslate:2,3c,3t `find . -name '*.cpp' -o -name '*.h'` -o $podir/marble.pot
-rm -f rc.cpp
+$XGETTEXT src/kdemain.cpp src/marble_part.cpp rc.cpp -o $podir/marble.pot
+$XGETTEXT_QT src/QtMainWindow.cpp src/qtmain.cpp `find src/plugins -name '*.cpp'` `find src/lib -name '*.cpp'` -o $podir/marble_qt.pot
