@@ -16,6 +16,9 @@
 #ifndef MARBLETEST_H
 #define MARBLETEST_H
 
+namespace Marble
+{
+
 class MarbleWidget;
 
 class MarbleTest {
@@ -26,8 +29,7 @@ class MarbleTest {
     void timeDemo();
     
     /**
-     * @brief load a gpx file and test the for average time, max time,
-     *        min time and total time
+     * @brief load a gpx file and test average, max, min, and total time
      */
     void gpsDemo();
 
@@ -35,4 +37,6 @@ class MarbleTest {
     MarbleWidget      *m_marbleWidget;
 };
 
+}
+
 #endif // MARBLETEST_H
