@@ -13,12 +13,14 @@
 #define SPHERICALSCANLINETEXTUREMAPPER_H
 
 
-#include <QtCore/QString>
 #include <QtGui/QColor>
 
 #include "AbstractScanlineTextureMapper.h"
 
 
+namespace Marble
+{
+
 class TileLoader;
 
 
@@ -41,15 +43,16 @@ class SphericalScanlineTextureMapper : public AbstractScanlineTextureMapper
     void mapTexture( ViewParams *viewParams );
 
  protected:
-    void pixelValueApprox(const double& lon, const double& lat,
+    void pixelValueApprox(const qreal& lon, const qreal& lat,
                           QRgb *scanLine, bool smooth );
 
     bool         m_interpolate;
     int          m_nBest;
 
     int     m_n;
-    double  m_nInverse;
+    qreal  m_nInverse;
 };
 
+}
 
 #endif // SPHERICALSCANLINETEXTUREMAPPER_H
