@@ -12,10 +12,23 @@
 #include "GeoDataLinearRing.h"
 
 
-GeoDataLinearRing::GeoDataLinearRing()
+namespace Marble
+{
+
+GeoDataLinearRing::GeoDataLinearRing( GeoDataObject *parent,
+                                      TessellationFlags f )
+    : GeoDataLineString( parent, f )
 {
 }
 
 GeoDataLinearRing::~GeoDataLinearRing()
 {
 }
+
+bool GeoDataLinearRing::isClosed() const
+{
+    return true;
+}
+
+}
+
