@@ -24,12 +24,18 @@
 
 #include "GeoTagHandler.h"
 
-class DgmlZoomTagHandler : public GeoTagHandler {
- public:
-    DgmlZoomTagHandler();
-    virtual ~DgmlZoomTagHandler();
+namespace Marble
+{
+namespace dgml
+{
 
+class DgmlZoomTagHandler : public GeoTagHandler
+{
+ public:
     virtual GeoNode* parse(GeoParser&) const;
 };
 
+}
+}
+
 #endif // DgmlZoomTagHandler_h
