@@ -24,12 +24,18 @@
 
 #include "GeoTagHandler.h"
 
-class KmlhrefTagHandler : public GeoTagHandler {
-public:
-    KmlhrefTagHandler();
-    virtual ~KmlhrefTagHandler();
+namespace Marble
+{
+namespace kml
+{
 
+class KmlhrefTagHandler : public GeoTagHandler
+{
+public:
     virtual GeoNode* parse(GeoParser&) const;
 };
 
+}
+}
+
 #endif // KmlhrefTagHandler_h
