@@ -23,6 +23,9 @@
 
 #include <limits>
 
+namespace Marble
+{
+
 // FIXME: Filters are a Dataset.
 
 GeoSceneAbstractDataset::GeoSceneAbstractDataset( const QString& name )
@@ -30,7 +33,6 @@ GeoSceneAbstractDataset::GeoSceneAbstractDataset( const QString& name )
       m_fileFormat( "" ),
       m_expire( std::numeric_limits<int>::max() )
 {
-    /* NOOP */
 }
 
 QString GeoSceneAbstractDataset::name() const
@@ -96,8 +98,8 @@ GeoSceneAbstractDataset* GeoSceneLayer::dataset( const QString& name )
 {
     GeoSceneAbstractDataset* dataset = 0;
 
-    QVector<GeoSceneAbstractDataset*>::const_iterator it = m_datasets.begin();
-    for (it = m_datasets.begin(); it != m_datasets.end(); ++it) {
+    QVector<GeoSceneAbstractDataset*>::const_iterator it = m_datasets.constBegin();
+    for (; it != m_datasets.constEnd(); ++it) {
         if ( (*it)->name() == name )
             dataset = *it;
     }
@@ -113,6 +115,14 @@ GeoSceneAbstractDataset* GeoSceneLayer::dataset( const QString& name )
     return dataset;
 }
 
+GeoSceneAbstractDataset* GeoSceneLayer::groundDataset() const
+{
+    if ( m_datasets.isEmpty() )
+        return 0;
+
+    return m_datasets.first();
+}
+
 QVector<GeoSceneAbstractDataset*> GeoSceneLayer::datasets() const
 {
     return m_datasets;
@@ -157,3 +167,5 @@ void GeoSceneLayer::removeFilter( GeoSceneFilter *filter )
 {
     if( filter == m_filter ) { m_filter = 0; }
 }
+
+}
