@@ -5,7 +5,8 @@
 // find a copy of this license in LICENSE.txt in the top directory of
 // the source code.
 //
-// Copyright 2007      Tobias Koenig  <tokoe@kde.org>"
+// Copyright 2007      Tobias Koenig  <tokoe@kde.org>
+// Copyright 2008      Inge Wallin    <inge@lysator.liu.se>
 //
 
 
@@ -44,21 +45,29 @@
 #include <kdeprintdialog.h>
 
 // Marble library
-#include "GeoDataPoint.h"
+#include "GeoDataCoordinates.h"
 #include "lib/SunControlWidget.h"
 
 // Local dir
-#include "ui_MarbleViewSettingsWidget.h"
-#include "ui_MarbleNavigationSettingsWidget.h"
 #include "MarbleCacheSettingsWidget.h"
 #include "MarblePluginSettingsWidget.h"
 
 #include <MarbleDirs.h>
 #include <ControlView.h>
+#include "global.h"
+#include "MarbleLocale.h"
 #include "settings.h"
 
 #include "MarbleAbstractFloatItem.h"
 
+using namespace Marble;
+
+#include "ui_MarbleViewSettingsWidget.h"
+#include "ui_MarbleNavigationSettingsWidget.h"
+
+namespace Marble
+{
+
 namespace
 {
     const char* POSITION_STRING = I18N_NOOP( "Position: %1" );
@@ -69,43 +78,51 @@ typedef KParts::GenericFactory< MarblePart > MarblePartFactory;
 K_EXPORT_COMPONENT_FACTORY( libmarble_part, MarblePartFactory )
 
 MarblePart::MarblePart( QWidget *parentWidget, QObject *parent, const QStringList &arguments )
-  : KParts::ReadOnlyPart( parent ), 
+  : KParts::ReadOnlyPart( parent ),
+    m_controlView( new ControlView( parentWidget ) ),
     m_sunControlDialog( 0 ),
     m_pluginModel( 0 ),
     m_configDialog( 0 ),
-    m_positionLabel( 0 ), 
+    m_positionLabel( 0 ),
     m_distanceLabel( 0 )
 {
     // only set marble data path when a path was given
-    if(arguments.count() != 0 && !arguments.first().isEmpty())
-      MarbleDirs::setMarbleDataPath(arguments.first());
+    if ( arguments.count() != 0 && !arguments.first().isEmpty() )
+        MarbleDirs::setMarbleDataPath( arguments.first() );
 
     setComponentData( MarblePartFactory::componentData() );
 
-    m_controlView = new ControlView( parentWidget );
     setWidget( m_controlView );
 
     setupActions();
 
-    readSettings();
-
     setXMLFile( "marble_part.rc" );
 
     m_statusBarExtension = new KParts::StatusBarExtension( this );
+    m_statusBarExtension->statusBar()->setUpdatesEnabled( false );
 
     m_position = NOT_AVAILABLE;
     m_distance = m_controlView->marbleWidget()->distanceString();
 
-    QTimer::singleShot( 0, this, SLOT( setupStatusBar() ) );
+    QTimer::singleShot( 0, this, SLOT( initObject() ) );
 }
 
 MarblePart::~MarblePart()
 {
     writeSettings();
-    delete m_pluginModel;
+
+    // Check whether this delete is really needed.
     delete m_configDialog;
 }
 
+void MarblePart::initObject()
+{
+    QCoreApplication::processEvents ();
+    setupStatusBar();
+    readSettings();
+    m_statusBarExtension->statusBar()->setUpdatesEnabled( true );
+}
+
 ControlView* MarblePart::controlView() const
 {
     return m_controlView;
@@ -113,7 +130,7 @@ ControlView* MarblePart::controlView() const
 
 KAboutData *MarblePart::createAboutData()
 {
-  	return new KAboutData( I18N_NOOP( "marble_part" ), 0, ki18n( "A Desktop Globe" ), "0.6.1" );
+  	return new KAboutData( I18N_NOOP( "marble_part" ), 0, ki18n( "A Desktop Globe" ), MARBLE_VERSION_STRING.toLatin1() );
 }
 
 bool MarblePart::openUrl( const KUrl &url )
@@ -154,7 +171,7 @@ void MarblePart::exportMapScreenShot()
     if ( !fileName.isEmpty() ) {
         // Take the case into account where no file format is indicated
         char * format = 0;
-        if ( !fileName.endsWith("png", Qt::CaseInsensitive) 
+        if ( !fileName.endsWith("png", Qt::CaseInsensitive)
            && !fileName.endsWith("jpg", Qt::CaseInsensitive) )
         {
             format = (char*)"JPG";
@@ -253,11 +270,13 @@ void MarblePart::showStatusBar( bool isChecked )
     m_statusBarExtension->statusBar()->setVisible( isChecked );
 }
 
-void MarblePart::showSun()
+void MarblePart::controlSun()
 {
-    if (!m_sunControlDialog) 
+    if ( !m_sunControlDialog ) {
         m_sunControlDialog = new SunControlWidget( NULL, m_controlView->sunLocator() );
-
+        connect( m_sunControlDialog, SIGNAL( showSun( bool ) ),
+                 this,               SLOT ( showSun( bool ) ) );
+    }
 
     m_sunControlDialog->show();
     m_sunControlDialog->raise();
@@ -265,6 +284,21 @@ void MarblePart::showSun()
 }
 
 
+void MarblePart::showSun( bool active )
+{
+    m_controlView->marbleWidget()->sunLocator()->setShow( active ); 
+}
+
+void MarblePart::workOffline( bool offline )
+{
+    if ( offline ) {
+        m_controlView->marbleWidget()->setDownloadManager( 0 );
+    }
+    else {
+        m_controlView->marbleWidget()->setDownloadUrl( "http://download.kde.org/apps/marble/" );
+    }
+}
+
 void MarblePart::copyMap()
 {
     QPixmap      mapPixmap = m_controlView->mapScreenShot();
@@ -275,20 +309,27 @@ void MarblePart::copyMap()
 
 void MarblePart::copyCoordinates()
 {
-    double lon = m_controlView->marbleWidget()->centerLongitude();
-    double lat = m_controlView->marbleWidget()->centerLatitude();
+    qreal lon = m_controlView->marbleWidget()->centerLongitude();
+    qreal lat = m_controlView->marbleWidget()->centerLatitude();
 
-    QString  positionString = GeoDataPoint( lon, lat, 0.0, GeoDataPoint::Degree ).toString();
+    QString  positionString = GeoDataCoordinates( lon, lat, 0.0, GeoDataCoordinates::Degree ).toString();
     QClipboard  *clipboard = QApplication::clipboard();
 
     clipboard->setText( positionString );
 }
 
+void MarblePart::setShowCurrentLocation( bool show )
+{
+    m_controlView->setCurrentLocationTabShown( show );
+//    m_controlView->setCurrentLocation2TabShown( show );
+}
+
 void MarblePart::readSettings()
-{ 
+{
+    qDebug() << "Start: MarblePart::readSettings()";
     // Last location on quit
     if ( MarbleSettings::onStartup() == Marble::LastLocationVisited ) {
-        m_controlView->marbleWidget()->centerOn( 
+        m_controlView->marbleWidget()->centerOn(
             MarbleSettings::quitLongitude(),
             MarbleSettings::quitLatitude()
         );
@@ -298,7 +339,7 @@ void MarblePart::readSettings()
     }
 
     // Set home position
-    m_controlView->marbleWidget()->setHome( 
+    m_controlView->marbleWidget()->setHome(
         MarbleSettings::homeLongitude(),
         MarbleSettings::homeLatitude(),
         MarbleSettings::homeZoom()
@@ -313,8 +354,17 @@ void MarblePart::readSettings()
 
     m_controlView->marbleWidget()->setShowClouds( MarbleSettings::showClouds() );
     m_showCloudsAction->setChecked( MarbleSettings::showClouds() );
+
+    workOffline( MarbleSettings::workOffline() );
+    m_workOfflineAction->setChecked( MarbleSettings::workOffline() );
+
+    setShowCurrentLocation( MarbleSettings::showCurrentLocation() );
+    m_currentLocationAction->setChecked( MarbleSettings::showCurrentLocation() );
+
     m_controlView->marbleWidget()->setShowAtmosphere( MarbleSettings::showAtmosphere() );
     m_showAtmosphereAction->setChecked( MarbleSettings::showAtmosphere() );
+    m_lockFloatItemsAct->setChecked(MarbleSettings::lockFloatItemPositions());
+    lockFloatItemPosition(MarbleSettings::lockFloatItemPositions());
 
     // Plugins
     QHash<QString, int> pluginEnabled;
@@ -322,32 +372,30 @@ void MarblePart::readSettings()
     int nameIdSize = MarbleSettings::pluginNameId().size();
     int enabledSize = MarbleSettings::pluginEnabled().size();
 
-    if ( nameIdSize == enabledSize )
-    {
-        for ( int i = 0; i < enabledSize; ++i ) 
-        {
-            pluginEnabled[ MarbleSettings::pluginNameId()[i] ] = MarbleSettings::pluginEnabled()[i];
+    if ( nameIdSize == enabledSize ) {
+        for ( int i = 0; i < enabledSize; ++i ) {
+            pluginEnabled[ MarbleSettings::pluginNameId()[i] ]
+		= MarbleSettings::pluginEnabled()[i];
         }
     }
 
-    QList<MarbleAbstractLayer *> pluginList = m_controlView->marbleWidget()->layerPlugins();    
-    QList<MarbleAbstractLayer *>::const_iterator i;
-    for (i = pluginList.constBegin(); i != pluginList.constEnd(); ++i)
-    {
-        if ( pluginEnabled.contains( (*i)->nameId() ) )
-        {
+    QList<MarbleRenderPlugin *> pluginList = m_controlView->marbleWidget()->renderPlugins();
+    QList<MarbleRenderPlugin *>::const_iterator i;
+    for (i = pluginList.constBegin(); i != pluginList.constEnd(); ++i) {
+        if ( pluginEnabled.contains( (*i)->nameId() ) ) {
             (*i)->setEnabled( pluginEnabled[ (*i)->nameId() ] );
             (*i)->item()->setCheckState( pluginEnabled[ (*i)->nameId() ]  ?  Qt::Checked : Qt::Unchecked );
         }
     }
 
     slotUpdateSettings();
+    qDebug() << "Stop: MarblePart::readSettings()";
 }
 
 void MarblePart::writeSettings()
 {
-    double  quitLon = m_controlView->marbleWidget()->centerLongitude();
-    double  quitLat = m_controlView->marbleWidget()->centerLatitude();
+    qreal  quitLon = m_controlView->marbleWidget()->centerLongitude();
+    qreal  quitLat = m_controlView->marbleWidget()->centerLatitude();
     int     quitZoom = m_controlView->marbleWidget()->zoom();
 
     // Get the 'home' values from the widget and store them in the settings.
@@ -355,8 +403,8 @@ void MarblePart::writeSettings()
     MarbleSettings::setQuitLatitude( quitLat );
     MarbleSettings::setQuitZoom( quitZoom );
 
-    double  homeLon = 0;
-    double  homeLat = 0;
+    qreal  homeLon = 0;
+    qreal  homeLat = 0;
     int     homeZoom = 0;
 
     // Get the 'home' values from the widget and store them in the settings.
@@ -378,11 +426,16 @@ void MarblePart::writeSettings()
     MarbleSettings::setProjection( m_controlView->marbleWidget()->projection() );
 
     MarbleSettings::setShowClouds( m_controlView->marbleWidget()->showClouds() );
+
+    MarbleSettings::setWorkOffline( m_workOfflineAction->isChecked() );
     MarbleSettings::setShowAtmosphere( m_controlView->marbleWidget()->showAtmosphere() );
 
+    MarbleSettings::setShowCurrentLocation( m_currentLocationAction->isChecked() );
+
     MarbleSettings::setStillQuality( m_controlView->marbleWidget()->mapQuality( Marble::Still ) );
     MarbleSettings::setAnimationQuality( m_controlView->marbleWidget()->mapQuality( Marble::Animation )  );
 
+    MarbleSettings::setDistanceUnit( MarbleGlobal::getInstance()->locale()->distanceUnit() );
     MarbleSettings::setAngleUnit( m_controlView->marbleWidget()->defaultAngleUnit() );
 
     // Caches
@@ -393,19 +446,20 @@ void MarblePart::writeSettings()
     MarbleSettings::setProxyUrl( m_controlView->marbleWidget()->proxyHost() );
     MarbleSettings::setProxyPort( m_controlView->marbleWidget()->proxyPort() );
 
-    QList<int> pluginEnabled;
-    QStringList pluginNameId;
+    QList<int>   pluginEnabled;
+    QStringList  pluginNameId;
 
-    QList<MarbleAbstractLayer *> pluginList = m_controlView->marbleWidget()->layerPlugins();    
-    QList<MarbleAbstractLayer *>::const_iterator i;
-    for (i = pluginList.constBegin(); i != pluginList.constEnd(); ++i)
-    {
-            pluginEnabled << static_cast<int>( (*i)->enabled() );
-            pluginNameId  << (*i)->nameId();
+    QList<MarbleRenderPlugin *> pluginList = m_controlView->marbleWidget()->renderPlugins();
+    QList<MarbleRenderPlugin *>::const_iterator i;
+    for (i = pluginList.constBegin(); i != pluginList.constEnd(); ++i) {
+	pluginEnabled << static_cast<int>( (*i)->enabled() );
+	pluginNameId  << (*i)->nameId();
     }
     MarbleSettings::setPluginEnabled( pluginEnabled );
     MarbleSettings::setPluginNameId(  pluginNameId );
-    
+
+    MarbleSettings::setLockFloatItemPositions( m_lockFloatItemsAct->isChecked() );
+
     MarbleSettings::self()->writeConfig();
 }
 
@@ -413,12 +467,11 @@ void MarblePart::setupActions()
 {
     // Adding some actions for translation
 
-    KAction action1(i18n("Open Map &Data..."), this);
-    KAction action2(i18n("&Import Map Data..."), this);
-    KAction action3(i18n("Scale &Bar"), this);
+    KAction action1( i18n("Open Map &Data..."), this );
+    KAction action2( i18n("&Import Map Data..."), this );
 
-    KAction action4(i18n("&Add Place"), this);
-    KAction action5(i18n("Panoramio Photos"), this);
+    KAction action4( i18n("&Add Place"), this );
+    KAction action5( i18n("Panoramio Photos"), this );
 
     // Action: Print Map
     m_printMapAction = KStandardAction::print( this, SLOT( printMapScreenShot() ), actionCollection() );
@@ -432,33 +485,54 @@ void MarblePart::setupActions()
     connect( m_exportMapAction, SIGNAL(triggered( bool ) ),
              this,              SLOT( exportMapScreenShot() ) );
 
+    // Action: Work Offline
+    m_workOfflineAction = new KAction( this );
+    actionCollection()->addAction( "workOffline", m_workOfflineAction );
+    m_workOfflineAction->setText( i18n( "&Work Offline" ) );
+    m_workOfflineAction->setIcon( KIcon( "user-offline" ) );
+    m_workOfflineAction->setCheckable( true );
+    m_workOfflineAction->setChecked( false );
+    connect( m_workOfflineAction, SIGNAL( triggered( bool ) ),
+             this,                SLOT( workOffline( bool ) ) );
+
+    // Action: Current Location
+    m_currentLocationAction = new KAction( this );
+    actionCollection()->addAction( "show_currentlocation", m_currentLocationAction );
+    m_currentLocationAction->setText( i18n( "Current Location" ) );
+    m_currentLocationAction->setCheckable( true );
+    m_currentLocationAction->setChecked( false );
+    connect( m_currentLocationAction, SIGNAL( triggered( bool ) ),
+             this,                SLOT( setShowCurrentLocation( bool ) ) );
+
     // Action: Copy Map to the Clipboard
-    m_copyMapAction = KStandardAction::copy( this, SLOT( copyMap() ), actionCollection() );
+    m_copyMapAction = KStandardAction::copy( this, SLOT( copyMap() ),
+					     actionCollection() );
     m_copyMapAction->setText( i18n( "&Copy Map" ) );
 
     // Action: Copy Coordinates string
     m_copyCoordinatesAction = new KAction( this );
-    actionCollection()->addAction( "edit_copy_coordinates", m_copyCoordinatesAction );
+    actionCollection()->addAction( "edit_copy_coordinates",
+				   m_copyCoordinatesAction );
     m_copyCoordinatesAction->setText( i18n( "C&opy Coordinates" ) );
-    connect( m_copyCoordinatesAction, SIGNAL( triggered( bool ) ), this, SLOT( copyCoordinates() ) );
+    connect( m_copyCoordinatesAction, SIGNAL( triggered( bool ) ),
+	     this,                    SLOT( copyCoordinates() ) );
 
     // Action: Open a Gpx or a Kml File
-    m_openAct = KStandardAction::open( this, SLOT( openFile() ), actionCollection() );
+    m_openAct = KStandardAction::open( this, SLOT( openFile() ),
+				       actionCollection() );
     m_openAct->setText( i18n( "&Open Map..." ) );
 
     // Standard actions.  So far only Quit.
-    KStandardAction::quit( kapp, SLOT( closeAllWindows() ), actionCollection() );
+    KStandardAction::quit( kapp, SLOT( closeAllWindows() ),
+			   actionCollection() );
 
     // Action: Get hot new stuff
-    m_newStuffAction = KNS::standardAction(QString(), this, SLOT(showNewStuffDialog()), actionCollection(), "new_stuff");
-    // FIXME: Enable the name and status tip when string freeze is lifted.
-#if 0
     m_newStuffAction = KNS::standardAction( i18n("Maps..."), this, SLOT(showNewStuffDialog()), actionCollection(), "new_stuff");
     m_newStuffAction->setStatusTip(i18n("&Download new maps"));
-#endif
     m_newStuffAction->setShortcut( Qt::CTRL + Qt::Key_N );
 
-    KStandardAction::showStatusbar( this, SLOT( showStatusBar( bool ) ), actionCollection() );
+    KStandardAction::showStatusbar( this, SLOT( showStatusBar( bool ) ),
+				    actionCollection() );
 
     m_sideBarAct = new KAction( i18n("Show &Navigation Panel"), this );
     actionCollection()->addAction( "options_show_sidebar", m_sideBarAct );
@@ -466,10 +540,13 @@ void MarblePart::setupActions()
     m_sideBarAct->setCheckable( true );
     m_sideBarAct->setChecked( true );
     m_sideBarAct->setStatusTip( i18n( "Show Navigation Panel" ) );
-    connect( m_sideBarAct, SIGNAL( triggered( bool ) ), this, SLOT( showSideBar( bool ) ) );
+    connect( m_sideBarAct, SIGNAL( triggered( bool ) ),
+	     this,         SLOT( showSideBar( bool ) ) );
 
-    m_fullScreenAct = KStandardAction::fullScreen( 0, 0, widget(), actionCollection() );
-    connect( m_fullScreenAct, SIGNAL( triggered( bool ) ), this, SLOT( showFullScreen( bool ) ) );
+    m_fullScreenAct = KStandardAction::fullScreen( 0, 0, widget(),
+						   actionCollection() );
+    connect( m_fullScreenAct, SIGNAL( triggered( bool ) ),
+	     this,            SLOT( showFullScreen( bool ) ) );
 
     // Action: Show Atmosphere option
     m_showAtmosphereAction = new KAction( this );
@@ -477,7 +554,18 @@ void MarblePart::setupActions()
     m_showAtmosphereAction->setCheckable( true );
     m_showAtmosphereAction->setChecked( true );
     m_showAtmosphereAction->setText( i18n( "&Atmosphere" ) );
-    connect( m_showAtmosphereAction, SIGNAL( triggered( bool ) ), this, SLOT( setShowAtmosphere( bool ) ) );
+    connect( m_showAtmosphereAction, SIGNAL( triggered( bool ) ),
+	     this,                   SLOT( setShowAtmosphere( bool ) ) );
+
+    // Action: Show Crosshairs option
+    QList<MarbleRenderPlugin *> pluginList = m_controlView->marbleWidget()->renderPlugins();
+    QList<MarbleRenderPlugin *>::const_iterator i;
+    for (i = pluginList.constBegin(); i != pluginList.constEnd(); ++i) {
+        if ( (*i)->nameId() == "crosshairs" ) {
+            actionCollection()->addAction( "show_crosshairs", (*i)->action() );
+        }
+    }
+
 
     // Action: Show Clouds option
     m_showCloudsAction = new KAction( this );
@@ -485,17 +573,28 @@ void MarblePart::setupActions()
     m_showCloudsAction->setCheckable( true );
     m_showCloudsAction->setChecked( true );
     m_showCloudsAction->setText( i18n( "&Clouds" ) );
-    connect( m_showCloudsAction, SIGNAL( triggered( bool ) ), this, SLOT( setShowClouds( bool ) ) );
+    connect( m_showCloudsAction, SIGNAL( triggered( bool ) ),
+	     this,               SLOT( setShowClouds( bool ) ) );
 
     // Action: Show Sunshade options
-    m_showSunAct = new KAction( this );
-    actionCollection()->addAction( "show_sun", m_showSunAct );
-    m_showSunAct->setText( i18n( "S&un Control" ) );
-    connect( m_showSunAct, SIGNAL( triggered( bool ) ), this, SLOT( showSun() ) );
+    m_controlSunAction = new KAction( this );
+    actionCollection()->addAction( "control_sun", m_controlSunAction );
+    m_controlSunAction->setText( i18n( "S&un Control..." ) );
+    connect( m_controlSunAction, SIGNAL( triggered( bool ) ),
+	     this,               SLOT( controlSun() ) );
 
-    KStandardAction::preferences( this, SLOT( editSettings() ), actionCollection() );
+    // Action: Lock float items
+    m_lockFloatItemsAct = new KAction ( this );
+    actionCollection()->addAction( "options_lock_floatitems",
+				   m_lockFloatItemsAct );
+    m_lockFloatItemsAct->setText( i18n( "Lock Position" ) );
+    m_lockFloatItemsAct->setCheckable( true );
+    m_lockFloatItemsAct->setChecked( false );
+    connect( m_lockFloatItemsAct, SIGNAL( triggered( bool ) ),
+	     this,                SLOT( lockFloatItemPosition( bool ) ) );
 
-    readSettings();
+    KStandardAction::preferences( this, SLOT( editSettings() ),
+				  actionCollection() );
 }
 
 void MarblePart::createInfoBoxesMenu()
@@ -505,10 +604,10 @@ void MarblePart::createInfoBoxesMenu()
     QList<QAction*> actionList;
 
     QList<MarbleAbstractFloatItem *>::const_iterator i;
-    for (i = floatItemList.constBegin(); i != floatItemList.constEnd(); ++i)
-    {
+    for (i = floatItemList.constBegin(); i != floatItemList.constEnd(); ++i) {
         actionList.append( (*i)->action() );
     }
+
     unplugActionList( "infobox_actionlist" );
     plugActionList( "infobox_actionlist", actionList );
 }
@@ -529,32 +628,33 @@ void MarblePart::showDistance( const QString& distance )
 void MarblePart::updateStatusBar()
 {
     if ( m_positionLabel )
-        m_positionLabel->setText( i18n( POSITION_STRING, m_position ) ); 
+        m_positionLabel->setText( i18n( POSITION_STRING, m_position ) );
 
     if ( m_distanceLabel )
-        m_distanceLabel->setText( i18n( DISTANCE_STRING, m_distance ) ); 
+        m_distanceLabel->setText( i18n( DISTANCE_STRING, m_distance ) );
 }
 
 void MarblePart::setupStatusBar()
 {
-
     QFontMetrics statusBarFontMetrics( m_statusBarExtension->statusBar()->fontMetrics() );
 
     m_positionLabel = new QLabel( m_statusBarExtension->statusBar() );
     m_positionLabel->setIndent( 5 );
-    QString templatePositionString = 
+    QString templatePositionString =
         QString( "%1 000\xb0 00\' 00\"_, 000\xb0 00\' 00\"_" ).arg(POSITION_STRING);
     int maxPositionWidth = statusBarFontMetrics.boundingRect(templatePositionString).width()
-                            + 2 * m_positionLabel->margin() + 2 * m_positionLabel->indent();
+	+ 2 * m_positionLabel->margin()
+	+ 2 * m_positionLabel->indent();
     m_positionLabel->setFixedWidth( maxPositionWidth );
     m_statusBarExtension->addStatusBarItem( m_positionLabel, -1, false );
 
     m_distanceLabel = new QLabel( m_statusBarExtension->statusBar() );
     m_distanceLabel->setIndent( 5 );
-    QString templateDistanceString = 
+    QString templateDistanceString =
         QString( "%1 00.000,0 mu" ).arg(DISTANCE_STRING);
     int maxDistanceWidth = statusBarFontMetrics.boundingRect(templateDistanceString).width()
-                            + 2 * m_distanceLabel->margin() + 2 * m_distanceLabel->indent();
+	+ 2 * m_distanceLabel->margin()
+	+ 2 * m_distanceLabel->indent();
     m_distanceLabel->setFixedWidth( maxDistanceWidth );
     m_statusBarExtension->addStatusBarItem( m_distanceLabel, -1, false );
 
@@ -568,7 +668,7 @@ void MarblePart::setupStatusBar()
 
 void MarblePart::showNewStuffDialog()
 {
-    QString  newStuffConfig = KStandardDirs::locate ( "data", 
+    QString  newStuffConfig = KStandardDirs::locate ( "data",
                                                       "marble/marble.knsrc" );
     kDebug() << "KNS config file:" << newStuffConfig;
 
@@ -580,63 +680,72 @@ void MarblePart::showNewStuffDialog()
 
     // Update the map theme widget by updating the model.
     // Shouldn't be needed anymore ...
-//    m_controlView->marbleControl()->updateMapThemes();
+    //m_controlView->marbleControl()->updateMapThemes();
 }
 
 void MarblePart::editSettings()
 {
     if ( KConfigDialog::showDialog( "settings" ) )
-        return; 
- 
-        m_configDialog = new KConfigDialog( m_controlView, "settings", MarbleSettings::self() ); 
+        return;
 
-        // view page
-        Ui_MarbleViewSettingsWidget ui_viewSettings;
-        QWidget *w_viewSettings = new QWidget( 0 );
-        w_viewSettings->setObjectName( "view_page" );
-        ui_viewSettings.setupUi( w_viewSettings );
-        m_configDialog->addPage( w_viewSettings, i18n( "View" ), "configure" );
+    m_configDialog = new KConfigDialog( m_controlView, "settings",
+					MarbleSettings::self() );
 
-        // navigation page
-        Ui_MarbleNavigationSettingsWidget ui_navigationSettings;
-        QWidget *w_navigationSettings = new QWidget( 0 );
-        w_navigationSettings->setObjectName( "navigation_page" );
-        ui_navigationSettings.setupUi( w_navigationSettings );
-        m_configDialog->addPage( w_navigationSettings, i18n( "Navigation" ), "transform-move" );
+    // view page
+    Ui_MarbleViewSettingsWidget  ui_viewSettings;
+    QWidget                     *w_viewSettings = new QWidget( 0 );
 
-        // cache page
-        MarbleCacheSettingsWidget *w_cacheSettings = 
-            new MarbleCacheSettingsWidget();
-        w_cacheSettings->setObjectName( "cache_page" );
-        m_configDialog->addPage( w_cacheSettings, i18n( "Cache & Proxy" ), "preferences-web-browser-cache" );
-        connect( w_cacheSettings, SIGNAL( clearVolatileCache() ), m_controlView->marbleWidget(), SLOT( clearVolatileTileCache() ) );
-        connect( w_cacheSettings, SIGNAL( clearPersistentCache() ), m_controlView->marbleWidget(), SLOT( clearPersistentTileCache() ) );
+    w_viewSettings->setObjectName( "view_page" );
+    ui_viewSettings.setupUi( w_viewSettings );
+    m_configDialog->addPage( w_viewSettings, i18n( "View" ), "configure" );
 
-        // plugin page
+    // navigation page
+    Ui_MarbleNavigationSettingsWidget  ui_navigationSettings;
+    QWidget                           *w_navigationSettings = new QWidget( 0 );
 
-        m_pluginModel = new QStandardItemModel();
-        QStandardItem *parentItem = m_pluginModel->invisibleRootItem();
+    w_navigationSettings->setObjectName( "navigation_page" );
+    ui_navigationSettings.setupUi( w_navigationSettings );
+    m_configDialog->addPage( w_navigationSettings, i18n( "Navigation" ),
+			     "transform-move" );
 
-        QList<MarbleAbstractLayer *> pluginList = m_controlView->marbleWidget()->layerPlugins();    
-        QList<MarbleAbstractLayer *>::const_iterator i;
-        for (i = pluginList.constBegin(); i != pluginList.constEnd(); ++i)
-        {
-            parentItem->appendRow( (*i)->item() );
-        }
+    // cache page
+    MarbleCacheSettingsWidget *w_cacheSettings = new MarbleCacheSettingsWidget();
+    w_cacheSettings->setObjectName( "cache_page" );
+    m_configDialog->addPage( w_cacheSettings, i18n( "Cache & Proxy" ),
+			     "preferences-web-browser-cache" );
+    connect( w_cacheSettings,               SIGNAL( clearVolatileCache() ),
+	     m_controlView->marbleWidget(), SLOT( clearVolatileTileCache() ) );
+    connect( w_cacheSettings,               SIGNAL( clearPersistentCache() ),
+	     m_controlView->marbleWidget(), SLOT( clearPersistentTileCache() ) );
 
-        MarblePluginSettingsWidget *w_pluginSettings = 
-            new MarblePluginSettingsWidget();
-        w_pluginSettings->setModel( m_pluginModel );
-        w_pluginSettings->setObjectName( "plugin_page" );
-        m_configDialog->addPage( w_pluginSettings, i18n( "Plugins" ), "preferences-plugin" );
+    // plugin page
+    m_pluginModel = new QStandardItemModel( this );
+    QStandardItem  *parentItem = m_pluginModel->invisibleRootItem();
 
-        connect( w_pluginSettings, SIGNAL( pluginListViewClicked() ), SLOT( slotEnableButtonApply() ) );
-        connect( m_configDialog, SIGNAL( settingsChanged( const QString &) ), SLOT( slotUpdateSettings() ) );
-        connect( m_configDialog, SIGNAL( applyClicked() ), SLOT( slotApply() ) );
-        connect( m_configDialog, SIGNAL( okClicked() ), SLOT( slotApply() ) );
-        connect( m_configDialog, SIGNAL( cancelClicked() ), SLOT( slotCancel() ) );
+    QList<MarbleRenderPlugin *>  pluginList = m_controlView->marbleWidget()->renderPlugins();
+    QList<MarbleRenderPlugin *>::const_iterator i;
+    for (i = pluginList.constBegin(); i != pluginList.constEnd(); ++i) {
+	parentItem->appendRow( (*i)->item() );
+    }
 
-        m_configDialog->show();
+    MarblePluginSettingsWidget *w_pluginSettings = new MarblePluginSettingsWidget();
+    w_pluginSettings->setModel( m_pluginModel );
+    w_pluginSettings->setObjectName( "plugin_page" );
+    m_configDialog->addPage( w_pluginSettings, i18n( "Plugins" ),
+			     "preferences-plugin" );
+
+    connect( w_pluginSettings, SIGNAL( pluginListViewClicked() ),
+	                       SLOT( slotEnableButtonApply() ) );
+    connect( m_configDialog,   SIGNAL( settingsChanged( const QString &) ),
+	                       SLOT( slotUpdateSettings() ) );
+    connect( m_configDialog,   SIGNAL( applyClicked() ),
+	                       SLOT( slotApply() ) );
+    connect( m_configDialog,   SIGNAL( okClicked() ),
+	                       SLOT( slotApply() ) );
+    connect( m_configDialog,   SIGNAL( cancelClicked() ),
+	                       SLOT( slotCancel() ) );
+
+    m_configDialog->show();
 }
 
 void MarblePart::slotEnableButtonApply()
@@ -646,20 +755,18 @@ void MarblePart::slotEnableButtonApply()
 
 void MarblePart::slotApply()
 {
-    QList<MarbleAbstractLayer *> pluginList = m_controlView->marbleWidget()->layerPlugins();    
-    QList<MarbleAbstractLayer *>::const_iterator i;
-    for (i = pluginList.constBegin(); i != pluginList.constEnd(); ++i)
-    {
+    QList<MarbleRenderPlugin *>  pluginList = m_controlView->marbleWidget()->renderPlugins();
+    QList<MarbleRenderPlugin *>::const_iterator  i;
+    for (i = pluginList.constBegin(); i != pluginList.constEnd(); ++i) {
         (*i)->applyItemState();
     }
 }
 
 void MarblePart::slotCancel()
 {
-    QList<MarbleAbstractLayer *> pluginList = m_controlView->marbleWidget()->layerPlugins();    
-    QList<MarbleAbstractLayer *>::const_iterator i;
-    for (i = pluginList.constBegin(); i != pluginList.constEnd(); ++i)
-    {
+    QList<MarbleRenderPlugin *>  pluginList = m_controlView->marbleWidget()->renderPlugins();
+    QList<MarbleRenderPlugin *>::const_iterator  i;
+    for (i = pluginList.constBegin(); i != pluginList.constEnd(); ++i) {
         (*i)->retrieveItemState();
     }
 }
@@ -668,12 +775,16 @@ void MarblePart::slotUpdateSettings()
 {
     qDebug() << "Updating Settings ...";
 
-    m_controlView->marbleWidget()->setDefaultFont( MarbleSettings::mapFont() );     
+    m_controlView->marbleWidget()->setDefaultFont( MarbleSettings::mapFont() );
 
     m_controlView->marbleWidget()->setMapQuality( (Marble::MapQuality) MarbleSettings::stillQuality(), Marble::Still );
     m_controlView->marbleWidget()->setMapQuality( (Marble::MapQuality) MarbleSettings::animationQuality(), Marble::Animation );
 
     m_controlView->marbleWidget()->setDefaultAngleUnit( (Marble::AngleUnit) MarbleSettings::angleUnit() );
+    MarbleGlobal::getInstance()->locale()->setDistanceUnit( (Marble::DistanceUnit) MarbleSettings::distanceUnit() );
+
+    m_distance = m_controlView->marbleWidget()->distanceString();
+    updateStatusBar();
 
     m_controlView->marbleWidget()->setAnimationsEnabled( MarbleSettings::animateTargetVoyage() );
 
@@ -686,4 +797,18 @@ void MarblePart::slotUpdateSettings()
     m_controlView->marbleWidget()->updateChangedMap();
 }
 
+void MarblePart::lockFloatItemPosition( bool enabled )
+{
+    QList<MarbleAbstractFloatItem *> floatItemList = m_controlView->marbleWidget()->floatItems();
+
+    QList<MarbleAbstractFloatItem *>::const_iterator i;
+    for (i = floatItemList.constBegin(); i != floatItemList.constEnd(); ++i) {
+        // Locking one would suffice as it affects all. 
+	// Nevertheless go through all.
+        (*i)->setPositionLocked(enabled);
+    }
+}
+
+}
+
 #include "marble_part.moc"
