@@ -90,7 +90,7 @@ int main(int argc, char *argv[])
 
 
 //    window->marbleWidget()->rotateTo( 0, 0, -90 );
-    window->show();
+//    window->show();
 
     for ( int i = 1; i < argc; ++i ) {
         if ( strcmp( argv[ i ], "--timedemo" ) == 0 )
