@@ -696,7 +696,7 @@ void NoteGraphicsItem::insertFormula()
 bool NoteGraphicsItem::editFormula(StepCore::NoteFormula* formula)
 {
     if(!LatexFormula::isLatexInstalled()) {
-        KMessageBox::sorry(_widget, i18n("Can not find latex installation. "
+        KMessageBox::sorry(_widget, i18n("Cannot find latex installation. "
                     "You need 'latex', 'dvips' and 'gs' executables installed and accessible from $PATH"));
         return false;
     }
@@ -859,7 +859,7 @@ void DataSourceWidget::objectSelected(int index)
             if(_skipReadOnly && !pr->isWritable()) continue;
             if(pr->userTypeId() == qMetaTypeId<double>() ||
                         pr->userTypeId() == qMetaTypeId<StepCore::Vector2d>()) {
-                _property->addItem(pr->name(), pr->name());
+                _property->addItem(pr->nameTr(), pr->name());
             }
         }
         propertySelected(_property->currentIndex());
